# API Reference

## biokb_coconut.import_data

::: biokb_coconut.import_data

## biokb_coconut.create_ttls

::: biokb_coconut.create_ttls

## biokb_coconut.import_ttls
::: biokb_coconut.import_ttls

## Command Line Interface (CLI)

### import_data
::: biokb_coconut.cli.import_data

### create_ttls
::: biokb_coconut.cli.create_ttls

### import_neo4j
::: biokb_coconut.cli.import_neo4j

### run_api
::: biokb_coconut.cli.run_api